use display_info::{get_display_info_from_point, get_display_infos};
use std::time::Instant;

fn main() {
  let start = Instant::now();

  let display_infos = get_display_infos();
  for display_info in display_infos {
    println!(
      "DisplayInfo:{} x: {} y: {} width: {} height: {} scale: {} rotation: {}\n",
      display_info.id,
      display_info.x,
      display_info.y,
      display_info.width,
      display_info.height,
      display_info.scale,
      display_info.rotation
    );
  }
  let display_info = get_display_info_from_point(100, 100).unwrap();
  println!("display_info {:?}", display_info);
  println!(
    "DisplayInfo:{} x: {} y: {} width: {} height: {} scale: {} rotation: {}\n",
    display_info.id,
    display_info.x,
    display_info.y,
    display_info.width,
    display_info.height,
    display_info.scale,
    display_info.rotation
  );
  println!("运行耗时: {:?}", start.elapsed());
}
